@@ -7,9 +7,10 @@ use Carp;
 use WWW::Mechanize;
 use HTML::Selector::XPath qw/selector_to_xpath/;
 use HTML::TreeBuilder::XPath;
+use HTML::Entities qw/decode_entities/;
 use Net::Kotonoha::Koto;
 
-our $VERSION = '0.01a';
+our $VERSION = '0.02';
 
 sub new {
     my $class = shift;
@@ -62,10 +63,11 @@ sub login {
 sub _get_list {
     my $self = shift;
     my $xpath = shift;
+    my $page = shift || 'http://kotonoha.cc/home';
 
     $self->login unless defined $self->{loggedin};
 
-    my $res = $self->{mech}->get('http://kotonoha.cc/home');
+    my $res = $self->{mech}->get( $page );
     croak "can't login kotonoha.cc" unless $res->is_success;
     return unless $res->is_success;
 
@@ -90,6 +92,39 @@ sub _get_list {
     return @list;
 }
 
+sub _get_stream {
+    my $self = shift;
+    my $xpath = shift;
+    my $page = shift || 'http://kotonoha.cc/stream';
+
+    $self->login unless defined $self->{loggedin};
+
+    my $res = $self->{mech}->get( $page );
+    croak "can't login kotonoha.cc" unless $res->is_success;
+    return unless $res->is_success;
+
+    my @list;
+
+    my $tree = HTML::TreeBuilder::XPath->new;
+    $tree->parse($res->content);
+    $tree->eof;
+    foreach my $line ($tree->findnodes(selector_to_xpath($xpath))) {
+        my $html = decode_entities($line->as_HTML);
+        if ($html =~ /<a href="\/user\/(\w+)">([^<]+)<\/a>[^<]+<a href="\/no\/(\d+)">([^<]+)<\/a>([^ ]+)( [^ ]+ (.+))?$/) {
+            push @list, {
+                user    => $1,
+                name    => $2,
+                comment => $7 || '',
+                answer  => $5,
+                koto_no => $3,
+                title   => $4,
+            }
+        }
+    }
+    $tree->delete;
+    return @list;
+}
+
 sub newer_list {
     return shift->_get_list('dl#newkoto a');
 }
@@ -98,6 +133,26 @@ sub recent_list {
     return shift->_get_list('dl#recentkoto a');
 }
 
+sub hot_list {
+    return shift->_get_list('dl#hot20 a');
+}
+
+sub answered_list {
+    return shift->_get_list('dl#answeredkoto a');
+}
+
+sub posted_list {
+    return shift->_get_list('dl#postedkoto a');
+}
+
+sub stream_list {
+    return shift->_get_stream('dl#stream li');
+}
+
+sub subscribed_list {
+    return shift->_get_stream('dl#subscribelist li', 'http://kotonoha.cc/inbox');
+}
+
 sub get_koto {
     my $self = shift;
     $self->login unless defined $self->{loggedin};
@@ -146,15 +201,18 @@ You have to sign-up your account at nowa if you don't have them.
 
 =head1 METHOD
 
-=head2 newer_list
+You can access koto list with following methods.
 
-You'll get newer koto list.
+  newer_list
+  recent_list
+  answered_list
+  posted_list
+  stream_list
+  subscribed_list
 
-=head2 recent_list
+And, you can get koto object with following method specified id of koto.
 
-You'll get recent update koto list.
-
-=head2 get_koto($koto_no)
+  get_koto($koto_no)
 
 You'll get koto object.
 see L<Net::Kotonoha::Koto>.
